@@ -1,28 +1,10 @@
 <?php
 
 /**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
-
 namespace OCA\Activity;
 
 use OC\Files\Filesystem;
@@ -96,7 +78,7 @@ class FilesHooks {
 		if ($this->currentUser->getUserIdentifier() !== '') {
 			$this->addNotificationsForFileAction($path, Files::TYPE_SHARE_CREATED, 'created_self', 'created_by');
 		} else {
-			$this->addNotificationsForFileAction($path, Files::TYPE_SHARE_CREATED, '', 'created_public');
+			$this->addNotificationsForFileAction($path, Files_Sharing::TYPE_PUBLIC_UPLOAD, '', 'created_public');
 		}
 	}
 
@@ -127,9 +109,9 @@ class FilesHooks {
 		$this->addNotificationsForFileAction($path, Files::TYPE_SHARE_RESTORED, 'restored_self', 'restored_by');
 	}
 
-	private function getFileChangeActivitySettings(int $fileId, array $users): array {
-		$filteredEmailUsers = $this->userSettings->filterUsersBySetting($users, 'email', Files::TYPE_FILE_CHANGED);
-		$filteredNotificationUsers = $this->userSettings->filterUsersBySetting($users, 'notification', Files::TYPE_FILE_CHANGED);
+	private function getFileChangeActivitySettings(int $fileId, array $users, $type = Files::TYPE_FILE_CHANGED): array {
+		$filteredEmailUsers = $this->userSettings->filterUsersBySetting($users, 'email', $type);
+		$filteredNotificationUsers = $this->userSettings->filterUsersBySetting($users, 'notification', $type);
 
 		/** @psalm-suppress UndefinedMethod */
 		$favoriteUsers = $this->tagManager->getUsersFavoritingObject('files', $fileId);
@@ -178,7 +160,7 @@ class FilesHooks {
 		}
 
 		[$filteredEmailUsers, $filteredNotificationUsers] =
-			$this->getFileChangeActivitySettings($fileId, array_keys($affectedUsers));
+			$this->getFileChangeActivitySettings($fileId, array_keys($affectedUsers), $activityType);
 
 		foreach ($affectedUsers as $user => $path) {
 			$user = (string)$user;
@@ -784,7 +766,7 @@ class FilesHooks {
 	 * @throws \OCP\Files\NotFoundException
 	 */
 	public function unShare(IShare $share) {
-		if (in_array($share->getNodeType(), ['file', 'folder'], true)) {
+		if (in_array($share->getNodeType(), ['file', 'folder'], true) && !$this->isDeletedNode($share->getShareOwner(), $share->getNodeId())) {
 			if ($share->getShareType() === IShare::TYPE_USER) {
 				$this->unshareFromUser($share);
 			} elseif ($share->getShareType() === IShare::TYPE_GROUP) {
@@ -1217,7 +1199,9 @@ class FilesHooks {
 				'provider' => str_replace('\\\\', '\\', $mount->getMountProvider()),
 				'path' => $mount->getPath(),
 				'visiblePath' => $this->getVisiblePath($mount->getPath()),
-				'storageId' => $mount->getStorageId()
+				'storageId' => $mount->getStorageId(),
+				'internalPath' => $mount->getInternalPath(),
+				'rootInternalPath' => $mount->getRootInternalPath(),
 			];
 		}
 
@@ -1247,6 +1231,8 @@ class FilesHooks {
 			return []; // if we have no access to RuleManager, we cannot filter unrelated users
 		}
 
+		$groupFolderAclStatus = [];
+
 		/** @var \OCA\GroupFolders\ACL\Rule[] $rules */
 		$rules = $knownRules = $knownGroupRules = $usersToCheck = $cachedPath = [];
 		foreach ($cachedMounts as $cachedMount) {
@@ -1267,16 +1253,21 @@ class FilesHooks {
 			if (!array_key_exists($cachedMount['visiblePath'], $knownRules[$storageId])) {
 				// we need mountPoint and folderId to generate the correct path
 				try {
-					$node = $this->rootFolder->get($fullPath);
-					$mountPoint = $node->getMountPoint();
+					// only check for groupfolders
+					if (!str_starts_with($cachedMount['rootInternalPath'], '__groupfolders')) {
+						continue;
+					}
 
-					if (!$mountPoint instanceof \OCA\GroupFolders\Mount\GroupMountPoint
-						|| !$folderManager->getFolderAclEnabled($mountPoint->getFolderId())) {
+					$folderId = (int)basename($cachedMount['rootInternalPath']);
+					if (!isset($groupFolderAclStatus[$folderId])) {
+						$groupFolderAclStatus[$folderId] = $folderManager->getFolderAclEnabled($folderId);
+					}
+					if (!$groupFolderAclStatus[$folderId]) {
 						continue; // acl are disable
 					}
 
-					$folderPath = $mountPoint->getSourcePath();
-					$path = substr($fullPath, strlen($mountPoint->getMountPoint()));
+					$folderPath = '/' . $cachedMount['rootInternalPath'];
+					$path = $cachedMount['internalPath'];
 				} catch (\Exception $e) {
 					// in case of issue during the process, we can imagine the user have no access to the file
 					$usersToCheck[] = $cachedMount['userId'];
@@ -1363,4 +1354,14 @@ class FilesHooks {
 
 		return $filteredUsers;
 	}
+
+	private function isDeletedNode(string $owner, int $nodeId): bool {
+		try {
+			$userFolder = $this->rootFolder->getUserFolder($owner);
+			$node = $userFolder->getFirstNodeById($nodeId);
+			return $node === null;
+		} catch (NotFoundException $e) {
+			return true;
+		}
+	}
 }
