@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "Beschreibung: %s",
     "Where: %s" : "Ort: %s",
     "%1$s via %2$s" : "%1$s über %2$s",
-    "In a %1$s on %2$s for the entire day" : "In einer %1$s am %2$s für den ganzen Tag",
-    "In a %1$s on %2$s between %3$s - %4$s" : "In einer %1$s am %2$s zwischen %3$s - %4$s",
-    "In %1$s %2$s on %3$s for the entire day" : "In %1$s %2$s am %3$s für den ganzen Tag",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "In %1$s %2$s am %3$s zwischen %4$s - %5$s",
+    "In the past on %1$s for the entire day" : "In der Vergangenheit am %1$s für den ganzen Tag",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["In einer Minute um %1$s für den ganzen Tag","In %n Minuten um %1$s für den ganzen Tag"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["In einer Stunde um %1$s für den ganzen Tag","In %n Stunden um %1$s für den ganzen Tag"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["In einem Tag am %1$s für den ganzen Tag","In %n Tagen am %1$s für den ganzen Tag"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["In einer Woche am %1$s den ganzen Tag","In %n Wochen am %1$s den ganzen Tag"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["In einem Monat am %1$s den ganzen Tag","In %n Monaten am %1$s den ganzen Tag"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["In einem Jahr am %1$s für den ganzen Tag","In %n Jahren am %1$s für den ganzen Tag"],
+    "In the past on %1$s between %2$s - %3$s" : "In der Vergangenheit am %1$s zwischen %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["In einer Minute am%1$s zwischen %2$s - %3$s","In %n Minuten am %1$s zwischen %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["In einer Stunde am %1$s zwischen %2$s - %3$s","In %n Stunden am%1$s zwischen %2$s - %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["In einem Tag am %1$s zwischen %2$s - %3$s","In %n Tagen am %1$szwischen %2$s - %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["In einer Woche am %1$s zwischen%2$s - %3$s","In %n Wochen am%1$s zwischen %2$s - %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["In einem Monat am %1$s zwischen %2$s - %3$s","In %n Monaten am %1$s zwischen %2$s - %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["In einem Jahr am %1$s zwischen %2$s - %3$s","In %n Jahren am%1$s zwischen %2$s - %3$s"],
     "Could not generate when statement" : "Wann-Angabe konnte nicht erzeugt werden.",
     "Every Day for the entire day" : "Jeden Tag für den ganzen Tag",
     "Every Day for the entire day until %1$s" : "Jeden Tag für den ganzen Tag bis %1$s",
@@ -112,12 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Alle %1$d Jahre im %2$s am %3$s zwischen %4$s - %5$s bis %6$s",
     "On specific dates for the entire day until %1$s" : "An bestimmten Tagen für den ganzen Tag bis %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "An bestimmten Tagen zwischen %1$s - %2$s bis %3$s",
-    "In a %1$s on %2$s" : "In einer %1$s am %2$s ",
-    "In a %1$s on %2$s then on %3$s" : "In einer %1$s am %2$s danach am %3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "In einer %1$s am %2$s danach am %3$s und %4$s",
-    "In %1$s %2$s on %3$s" : "In %1$s %2$s am %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "In %1$s %2$s am %3$s danach am %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "In %1$s %2$s am %3$s danach am %4$s und %5$s",
+    "In the past on %1$s" : "In der Vergangenheit am %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["In einer Minute am %1$s","In %n Minuten am %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["In einer Stunde am %1$s","In %n Stunden am %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["In einem Tag am %1$s","In %n Tagen am %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["In einer Woche am %1$s","In %n Wochen am %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["In einem Monat am %1$s","In %n Monaten am %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["In einem Jahr am %1$s","In %n Jahren am %1$s"],
+    "In the past on %1$s then on %2$s" : "In der Vergangenheit am %1$s danach am %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["In einer Minute am %1$s danach am %2$s","In %n Minuten am %1$s danach am %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["In einer Stunde am %1$s danach am %2$s","In %n Stunden am %1$s danach am %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["In einem Tag am %1$s danach am %2$s","In %n Tagen am %1$s danach am %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["In einer Woche am %1$s danach am %2$s","In %n Wochen am %1$s danach am %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["In einem Monat am %1$s danach am %2$s","In %n Monaten am %1$s danach am %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["In einem Jahr am %1$s danach am %2$s","In %n Jahren am %1$s danach am %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "In der Vergangenheit am %1$s danach am %2$s und %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["In einer Minute am %1$s danach am %2$s und %3$s","In %n Minuten am %1$s danach am %2$s und %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["In einer Stunde am %1$s danach am %2$s und %3$s","In %n Stunden am %1$s danach am %2$s und %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["In einem Tag am %1$s danach am %2$s und %3$s","In %n Tagen am %1$s danach am %2$s und %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["In einer Woche am %1$s danach am %2$s und %3$s","In %n Wochen am %1$s danach am %2$s und %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["In einem Monat am %1$s danach am %2$s und %3$s","In %n Monaten am %1$s danach am %2$s und %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["In einem Jahr am %1$s danach am %2$s und %3$s","In %n Jahren am %1$s danach am %2$s und %3$s"],
     "Could not generate next recurrence statement" : "Angabe für nächste Wiederholung konnte nicht erzeugt werden.",
     "Cancelled: %1$s" : "Abgesagt: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" wurde abgesagt.",
@@ -161,15 +186,15 @@ OC.L10N.register(
     "November" : "November",
     "December" : "Dezember",
     "First" : "Erste",
-    "Second" : "2.",
-    "Third" : "3.",
-    "Fourth" : "4.",
-    "Fifty" : "5.",
+    "Second" : "Zweite",
+    "Third" : "Dritte",
+    "Fourth" : "Vierte",
+    "Fifth" : "Fünften",
     "Last" : "Letzte",
     "Second Last" : "Vorletztes",
     "Third Last" : "Drittletztes",
     "Fourth Last" : "Viertletztes",
-    "Fifty Last" : "Fünftletztes",
+    "Fifth Last" : "Fünftletztes",
     "Contacts" : "Kontakte",
     "{actor} created address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} erstellt",
     "You created address book {addressbook}" : "Du hast das Adressbuch {addressbook} erstellt",
@@ -198,6 +223,7 @@ OC.L10N.register(
     "Accounts" : "Konten",
     "System address book which holds all accounts" : "Systemadressbuch, das alle Konten enthält",
     "File is not updatable: %1$s" : "Datei kann nicht aktualisiert werden: %1$s",
+    "Failed to get storage for file" : "Speicherplatz für Datei konnte nicht abgerufen werden",
     "Could not write to final file, canceled by hook" : "In die endgültige Datei konnte nicht geschrieben werden, wurde durch einen Hook abgebrochen",
     "Could not write file contents" : "Dateiinhalt konnte nicht  geschrieben werden",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
@@ -206,7 +232,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen, wurde durch einen Hook abgebrochen",
     "Could not rename part file to final file" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen",
     "Failed to check file size: %1$s" : "Dateigröße konnte nicht überprüft werden: %1$s",
-    "Could not open file" : "Datei konnte nicht geöffnet werden",
+    "Could not open file: %1$s, file does seem to exist" : "Datei konnte nicht geöffnet werden: %1$s, Datei scheint aber zu existieren.",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Datei konnte nicht geöffnet werden: %1$s, Datei scheint nicht zu existieren.",
     "Encryption not ready: %1$s" : "Verschlüsselung nicht bereit: %1$s",
     "Failed to open file: %1$s" : "Datei konnte nicht geöffnet werden: %1$s",
     "Failed to unlink: %1$s" : "Fehler beim Aufheben der Verknüpfung: %1$s",
@@ -223,31 +250,37 @@ OC.L10N.register(
     "Completed on %s" : "Erledigt am %s",
     "Due on %s by %s" : "Fällig am %s von %s",
     "Due on %s" : "Fällig am %s",
+    "System Address Book" : "Systemadressbuch",
+    "The system address book contains contact information for all users in your instance." : "Das Systemadressbuch enthält Kontaktinformationen für alle Benutzer in dieser Instanz.",
+    "Enable System Address Book" : "Systemadressbuch aktivieren",
     "DAV system address book" : "DAV-Systemadressbuch",
     "No outstanding DAV system address book sync." : "Keine ausstehende Synchronisierung des DAV-Systemadressbuchs",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du \"occ dav:sync-system-addressbook\" ausführst.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da diese Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte manuell ausführen, mittels \"occ dav:sync-system-addressbook\".",
     "WebDAV endpoint" : "WebDAV-Endpunkt",
-    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob dein Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte überprüfe dies manuell.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
-    "Your web server is properly set up to allow file synchronization over WebDAV." : "Dein Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob der Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte dies manuell überprüfen.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Der Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Der Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
     "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
     "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
     "Contacts and groups" : "Kontakte und Gruppen",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Abwesenheit gespeichert",
+    "Failed to save your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gespeichert werden.",
+    "Absence cleared" : "Abwesenheit gelöscht",
+    "Failed to clear your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gelöscht werden.",
     "First day" : "Erster Tag",
     "Last day (inclusive)" : "Letzter Tag (Inklusive)",
     "Out of office replacement (optional)" : "Abwesenheitsvertretung (optional)",
     "Name of the replacement" : "Name der Vertretung",
     "No results." : "Keine Ergebnisse",
-    "Start typing." : "Beginne mit Schreiben",
-    "Short absence status" : "Kurze Abwesenheits Meldung",
-    "Long absence Message" : "Lange Abwesenheits Meldung",
+    "Start typing." : "Mit dem Schreiben beginnen.",
+    "Short absence status" : "Kurzer Abwesenheitsstatus",
+    "Long absence Message" : "Lange Abwesenheitsnachricht",
     "Save" : "Speichern",
-    "Disable absence" : "Abwesenheitmeldungen deaktivieren",
-    "Absence saved" : "Abwesenheit gespeichert",
-    "Failed to save your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gespeichert werden.",
-    "Absence cleared" : "Abwesenheit gelöscht",
-    "Failed to clear your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gelöscht werden.",
+    "Disable absence" : "Abwesenheit deaktivieren",
+    "Failed to load availability" : "Verfügbarkeit konnte nicht geladen werden",
+    "Saved availability" : "Verfügbarkeit gespeichert",
+    "Failed to save availability" : "Verfügbarkeit konnte nicht gespeichert werden",
     "Time zone:" : "Zeitzone:",
     "to" : "an",
     "Delete slot" : "Slot löschen",
@@ -256,14 +289,13 @@ OC.L10N.register(
     "Weekdays" : "Wochentage",
     "Pick a start time for {dayName}" : "Eine Startzeit für {dayName} wählen",
     "Pick a end time for {dayName}" : "Eine Endezeit für {dayName} wählen",
-    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setze den Benutzerstatus automatisch auf „Nicht stören“, wenn du nicht erreichbar bist, um alle Benachrichtigungen stumm zu schalten.",
-    "Failed to load availability" : "Fehler beim Laden der Verfügbarkeit",
-    "Saved availability" : "Verfügbarkeit gespeichert",
-    "Failed to save availability" : "Fehler beim Speichern der Verfügbarkeit",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setze den Benutzerstatus außerhalb deiner Verfügbarkeit automatisch auf \"Nicht stören\", um alle Benachrichtigungen stumm zu schalten.",
     "Availability" : "Verfügbarkeit",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten angibst, können andere beim Buchen einer Besprechung sehen, wann du nicht im Büro bist.",
     "Absence" : "Abwesenheit",
     "Configure your next absence period." : "Richte deinen nächsten Abwesenheitszeitraum ein.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinde deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
     "Calendar server" : "Kalender-Server",
     "Send invitations to attendees" : "Einladungen an die Teilnehmer senden",
     "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
@@ -274,17 +306,27 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die freigegebenen Kalender senden",
     "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
     "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinde deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
+    "Cancel" : "Abbrechen",
+    "Import" : "Importieren",
+    "Error while saving settings" : "Fehler beim Speichern der Einstellungen",
+    "Contact reset successfully" : "Kontakt zurückgesetzt",
+    "Error while resetting contact" : "Fehler beim Zurücksetzen des Kontakts",
+    "Contact imported successfully" : "Kontakt importiert",
+    "Error while importing contact" : "Fehler beim Import des Kontakts",
+    "Example Content" : "Beispielinhalt",
+    "Set example content to be created on new user first login." : "Beispielinhalte festlegen, die bei der ersten Anmeldung eines neuen Benutzers erstellt werden sollen.",
+    "Import contact" : "Kontakt importieren",
+    "Reset to default contact" : "Standardkontakt zurücksetzen",
+    "Import contacts" : "Kontakte importieren",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Durch das Importieren einer neuen VCF-Datei wird der vorhandene Standardkontakt gelöscht und durch den neuen ersetzt. Fortsetzen?",
     "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren deines Teilnehmerstatus aufgetreten.",
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
     "Tentative" : "Vorläufig",
     "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert.",
-    "To-dos" : "Aufgaben",
     "Time:" : "Zeit:",
+    "Could not open file" : "Datei konnte nicht geöffnet werden",
     "Invalid chunk name" : "Ungültiger Chunk-Name",
-    "Could not rename part file assembled from chunks" : "Aus Chunks zusammengesetzte temporäre Datei konnte nicht umbenannt werden",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen."
+    "Could not rename part file assembled from chunks" : "Aus Chunks zusammengesetzte temporäre Datei konnte nicht umbenannt werden"
 },
 "nplurals=2; plural=(n != 1);");
