@@ -274,26 +274,26 @@ OC.L10N.register(
     "Name of the replacement" : "Name der Vertretung",
     "No results." : "Keine Ergebnisse.",
     "Start typing." : "Anfangen zu tippen.",
-    "Short absence status" : "Kurzer Abwesenheitsstaus",
+    "Short absence status" : "Kurzer Abwesenheitsstatus",
     "Long absence Message" : "Lange Abwesenheitsnachricht",
     "Save" : "Speichern",
     "Disable absence" : "Abwesenheit deaktivieren",
-    "Failed to load availability" : "Laden der Verfügbarkeit fehlgeschlagen",
+    "Failed to load availability" : "Verfügbarkeit konnte nicht geladen werden",
     "Saved availability" : "Verfügbarkeit gespeichert",
-    "Failed to save availability" : "Fehler beim Speichern der Verfügbarkeit",
+    "Failed to save availability" : "Verfügbarkeit konnte nicht gespeichert werden",
     "Time zone:" : "Zeitzone:",
     "to" : "an",
     "Delete slot" : "Zeitfenster löschen",
-    "No working hours set" : "Arbeitsfreie Stunden gesetzt",
+    "No working hours set" : "Keine Arbeitszeiten konfiguriert",
     "Add slot" : "Zeitfenster hinzufügen",
     "Weekdays" : "Wochentage",
     "Pick a start time for {dayName}" : "Eine Startzeit für {dayName} wählen",
     "Pick a end time for {dayName}" : "Eine Endezeit für {dayName} wählen",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setzen Sie den Benutzerstatus außerhalb Ihrer Verfügbarkeit automatisch auf \"Nicht stören\", um alle Benachrichtigungen stumm zu schalten.",
     "Availability" : "Verfügbarkeit",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn Sie Ihre Arbeitszeiten angeben, können Andere beim Buchen einer Besprechung sehen, wann Sie nicht im Büro sind.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn Sie Ihre Arbeitszeiten angeben, können andere beim Buchen einer Besprechung sehen, wann Sie nicht im Büro sind.",
     "Absence" : "Abwesenheit",
-    "Configure your next absence period." : "Richten Sie ihren nächsten Abwesenheitszeitraum ein",
+    "Configure your next absence period." : "Richten Sie ihren nächsten Abwesenheitszeitraum ein.",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installieren Sie außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinden Sie Ihren Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stellen Sie sicher, dass Sie {emailopen}den E-Mail Server{linkclose} ordnungsgemäß eingerichtet haben.",
     "Calendar server" : "Kalender-Server",
@@ -306,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die Kalenderfreigaben senden",
     "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
     "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
+    "Cancel" : "Abbrechen",
+    "Import" : "Importieren",
+    "Error while saving settings" : "Fehler beim Speichern der Einstellungen",
+    "Contact reset successfully" : "Kontakt zurückgesetzt",
+    "Error while resetting contact" : "Fehler beim Zurücksetzen des Kontakts",
+    "Contact imported successfully" : "Kontakt importiert",
+    "Error while importing contact" : "Fehler beim Import des Kontakts",
+    "Example Content" : "Beispielinhalt",
+    "Set example content to be created on new user first login." : "Beispielinhalte festlegen, die bei der ersten Anmeldung eines neuen Benutzers erstellt werden sollen.",
+    "Import contact" : "Kontakt importieren",
+    "Reset to default contact" : "Standardkontakt zurücksetzen",
+    "Import contacts" : "Kontakte importieren",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Durch das Importieren einer neuen VCF-Datei wird der vorhandene Standardkontakt gelöscht und durch den neuen ersetzt. Fortsetzen?",
     "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Ihres Teilnehmerstatus aufgetreten.",
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
