@@ -303,6 +303,9 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Enviar notificacións de lembrete tamén aos que comparten calendario",
     "Reminders are always sent to organizers and attendees." : "Os lembretes envíanselle sempre aos organizadores e aos asistentes.",
     "Enable notifications for events via push" : "Activar o envío de notificacións emerxentes para eventos",
+    "Cancel" : "Cancelar",
+    "Import" : "Importar",
+    "Error while saving settings" : "Produciuse un erro ao gardar os axustes",
     "There was an error updating your attendance status." : "Produciuse un erro ao actualizar o seu estado de asistencia.",
     "Please contact the organizer directly." : "Contacte directamente co organizador.",
     "Are you accepting the invitation?" : "Acepta Vde. o convite?",
