@@ -1,11 +1,6 @@
-/*
- * Copyright (c) 2016
- *
- * This file is licensed under the Affero General Public License version 3
- * or later.
- *
- * See the COPYING-README file.
- *
+/**
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 (function () {
@@ -18,7 +13,6 @@
 		},
 
 		handlePreview: function (model, $thumbnailDiv, $thumbnailContainer, fallback) {
-			console.log(model);
 			var previewWidth = $thumbnailContainer.parent().width() + 50;  // 50px for negative margins
 			var previewHeight = previewWidth / (16 / 9);
 
@@ -26,7 +20,7 @@
 				$thumbnailDiv.removeClass('icon-loading icon-32');
 				$thumbnailContainer.addClass('large');
 				$thumbnailContainer.addClass('text');
-				var $textPreview = $('<pre/>').text(content);
+				var $textPreview = $('<pre></pre>').text(content);
 				$thumbnailDiv.children('.stretcher').remove();
 				$thumbnailDiv.append($textPreview);
 				$thumbnailContainer.css("max-height", previewHeight);
@@ -36,10 +30,12 @@
 		},
 
 		getFileContent: function (path) {
-			console.log(path);
-			var url = OC.linkToRemoteBase('files' + path);
-			console.log(url);
-			return $.get(url);
+			return $.ajax({
+				url: OC.linkToRemoteBase('files' + path),
+				headers: {
+					'Range': 'bytes=0-10240'
+				}
+			});
 		}
 	};
 
