@@ -46,7 +46,11 @@ OC.L10N.register(
     "Failed to authorize" : "Ezin izan da baimendu",
     "Invalid folder path" : "Karpeta bide baliogabea",
     "Folder not found" : "Ez da karpeta aurkitu",
+    "You do not have permission to create a file at the specified location" : "Ez duzu baimenik fitxategia sortzeko zehaztutako tokian",
+    "The file could not be converted." : "Fitxategia ezin izan da bihurtu.",
+    "Favorite files" : "Gogoko fitxategiak",
     "No favorites" : "Gogokorik ez",
+    "More favorites" : "Gogoko gehiago",
     "Upload (max. %s)" : "Igo (%s gehienez)",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
@@ -67,68 +71,61 @@ OC.L10N.register(
     "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
     "File Management" : "Fitxategi-kudeaketa",
-    "Current directory path" : "Uneko direktorio-bidea",
     "Home" : "Etxea",
     "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
     "Reload current directory" : "Birkargatu uneko direktorioa",
     "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
-    "Drag and drop files here to upload" : "Jaregin fitxategiak hemen igotzeko",
+    "Current directory path" : "Uneko direktorio-bidea",
     "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
-    "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
+    "Drag and drop files here to upload" : "Jaregin fitxategiak hemen igotzeko",
     "Favorite" : "Gogokoa",
     "Back" : "Itzuli",
     "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
     "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
     "File is loading" : "Fitxategia kargatzen ari da",
     "Folder is loading" : "Karpeta kargatzen ari da",
-    "Rename file" : "Berrizendatu fitxategia",
     "Filename" : "Fitxategi-izena",
     "Folder name" : "Karpetaren izena",
     "This node is unavailable" : "Nodo hori ez dago erabilgarri",
     "Another entry with the same name already exists." : "Izen bereko beste sarrera bat badago jada.",
     "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
-    "Unknown date" : "Data ezezaguna",
+    "Rename file" : "Berrizendatu fitxategia",
+    "Folder" : "Karpeta",
     "Pending" : "Zain",
+    "Unknown date" : "Data ezezaguna",
     "Clear filter" : "Garbitu iragazkia",
     "Modified" : "Aldatuta",
     "Type" : "Mota",
     "Active filters" : "Iragazki aktiboak",
     "Remove filter" : "Kendu iragazkia",
     "Total rows summary" : "Errenkaden guztirako laburpena",
+    "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
     "Name" : "Izena",
     "Size" : "Tamaina",
-    "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
-    "Actions" : "Ekintzak",
-    "(selected)" : "(hautatuta)",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
     "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
-    "{count} selected" : "{count} hautatuta",
+    "Actions" : "Ekintzak",
+    "(selected)" : "(hautatuta)",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
-    "You don’t have permission to upload or create files here." : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko.",
     "You have used your space quota and cannot upload files anymore." : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu.",
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
-    "Storage information" : "Biltegiaren informazioa",
-    "Storage quota" : "Biltegiratze-kuota",
+    "{count} selected" : "{count} hautatuta",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{used} of {quota} used" : "{used} / {quota} erabilita",
     "{relative}% used" : "%{relative} erabilita",
     "Could not refresh storage stats" : "Ezin izan da biltegiratze maila freskatu",
     "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
-    "Create" : "Sortu",
+    "Storage information" : "Biltegiaren informazioa",
+    "Storage quota" : "Biltegiratze-kuota",
     "New folder" : "Karpeta berria",
     "Create new folder" : "Sortu karpeta berria",
     "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
+    "Create" : "Sortu",
     "Fill template fields" : "Bete txantiloien eremuak",
-    "Submitting fields…" : "Eremuak bidaltzen…",
     "Submit" : "Bidali",
-    "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
-    "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
-    "Change" : "Aldatu",
-    "New owner" : "Jabe berria",
     "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
     "Transfer" : "Transferitu",
     "Transfer {path} to {userid}" : "Transfereritu {path}  {userid} erabiltzaileari",
@@ -136,13 +133,18 @@ OC.L10N.register(
     "Unknown error" : "Errore ezezaguna",
     "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
     "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
+    "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
+    "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
+    "Change" : "Aldatu",
+    "New owner" : "Jabe berria",
+    "Use {new}" : "Erabili {new}",
+    "Remove extension" : "Kendu luzapena",
+    "Change file extension" : "Aldatu fitxategiaren luzapena",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Fitxategiaren luzapena «{old}»(e)tik «{new}»(e)ra aldatzeak irakurezin bihur dezake.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» fitxategiaren luzapena kentzeak fitxategia irakurezin bihur dezake.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» fitxategiaren luzapena gehitzeak fitxategia irakurezin bihur dezake.",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
     "Choose {file}" : "Aukeratu {file}",
-    "Loading current folder" : "Uneko karpeta kargatzen",
-    "Retry" : "saiatu berriro",
-    "No files in here" : "Ez dago fitxategirik hemen",
-    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
-    "Go back" : "Atzera",
     "Share" : "Partekatu",
     "Shared by link" : "Esteka bidez partekatuta",
     "Shared" : "Partekatuta",
@@ -155,12 +157,19 @@ OC.L10N.register(
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
+    "Loading current folder" : "Uneko karpeta kargatzen",
+    "Retry" : "saiatu berriro",
+    "No files in here" : "Ez dago fitxategirik hemen",
+    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
+    "Go back" : "Atzera",
     "Views" : "Ikuspegiak",
     "Files settings" : "FItxategien ezarpenak",
-    "File cannot be accessed" : "Ezin da fitxategia atzitu",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
     "Your files" : "Zure fitxategiak",
     "Open in files" : "Ireki Fitxategiak aplikazioan",
+    "File cannot be accessed" : "Ezin da fitxategia atzitu",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
+    "Clipboard is not available" : "Arbela ez dago erabilgarri",
+    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Sort favorites first" : "Ordenatu gogokoak lehenengo",
     "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
@@ -195,20 +204,18 @@ OC.L10N.register(
     "Toggle the grid view" : "Txandakatu sareta ikuspegia",
     "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
     "Show those shortcuts" : "Erakutsi lasterbide horiek",
-    "Clipboard is not available" : "Arbela ez dago erabilgarri",
-    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
+    "You" : "Zu ",
+    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
+    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
     "Owner" : "Jabea",
     "Remove from favorites" : "Kendu gogokoetatik",
     "Add to favorites" : "Gehitu gogokoetara",
     "Tags" : "Etiketak",
-    "You" : "Zu ",
-    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
-    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
+    "Blank" : "Hutsik",
+    "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
-    "Blank" : "Hutsik",
-    "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
     "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
     "Leave this share" : "Utzi partekatze hau",
     "Leave these shares" : "Utzi partekatze hauek",
@@ -225,12 +232,6 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Elementu {count} ezabatzera zoaz"," {count}  elementu ezabatzera zoaz"],
     "Confirm deletion" : "Berretsi ezabaketa",
     "Cancel" : "Utzi",
-    "Edit file locally" : "Editatu fitxategia lokalean",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
-    "Retry and close" : "Saiatu berriro eta itxi",
-    "Edit online" : "Editatu sarean",
-    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
-    "Edit locally" : "Editatu lokalean",
     "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
@@ -251,6 +252,11 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
+    "Open file locally" : "Ireki fitxategia lokalean",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
+    "Retry and close" : "Saiatu berriro eta itxi",
+    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
+    "Open locally" : "Ireki lokalean",
     "Rename" : "Berrizendatu",
     "Open details" : "Ireki xehetasunak",
     "View in folder" : "Ikusi karpetan",
@@ -288,22 +294,12 @@ OC.L10N.register(
     "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
     "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
     "Upload cancelled" : "Igotzea bertan behera utzi da",
-    "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» fitxategiaren luzapena gehitzeak fitxategia irakurezin bihur dezake.",
-    "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» fitxategiaren luzapena kentzeak fitxategia irakurezin bihur dezake.",
-    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Fitxategiaren luzapena «{old}»(e)tik «{new}»(e)ra aldatzeak irakurezin bihur dezake.",
-    "Change file extension" : "Aldatu fitxategiaren luzapena",
-    "Keep {oldextension}" : "Mantendu {oldextension}",
-    "Use {newextension}" : "Erabili {newextension}",
-    "Remove extension" : "Kendu luzapena",
     "This operation is forbidden" : "Eragiketa hau debekatuta dago",
     "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Unexpected error: {error}" : "Ustekabeko errorea: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
-    "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
+    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
+    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
     "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
@@ -323,7 +319,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Azkenaldian aldatutako fitxategi eta karpeten zerrenda.",
     "No recently modified files" : "Ez dago azkenaldian aldatutako fitxategirik",
     "Files and folders you recently modified will show up here." : "Azkenaldian aldatu dituzun fitxategi eta karpetak hemen agertuko dira.",
-    "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak igotzeko edo sortzeko baimenik",
     "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
     "Select all" : "Hautatu dena",
     "Upload too large" : "Igotzekoa handiegia da",
@@ -351,6 +346,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Errorea zatiak elkartzean, egoera kodea {status}",
     "Choose target folder" : "Aukeratu helburuko karpeta",
     "Set reminder" : "Ezarri gogorarazpena",
+    "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
     "Details" : "Xehetasunak",
@@ -377,10 +373,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
     "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
-    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
-    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
     "{dirs} and {files}" : "{dirs} eta {files}",
     "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
+    "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak igotzeko edo sortzeko baimenik",
     "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi igotzen"],
     "New" : "Berria",
     "New file/folder menu" : "Fitxategi/karpeta berri menua",
@@ -413,7 +408,14 @@ OC.L10N.register(
     "Go to the previous folder" : "Joan aurreko karpetara",
     "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
     "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
+    "Edit file locally" : "Editatu fitxategia lokalean",
+    "Edit online" : "Editatu sarean",
     "Create new templates folder" : "Sortu txantiloi karpeta berria",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
+    "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
     "List of favorites files and folders." : "Fitxategi eta karpeta gogokoen zerrenda.",
     "Personal Files" : "Fitxategi pertsonalak",
     "Text file" : "Testu-fitxategia",
@@ -421,6 +423,7 @@ OC.L10N.register(
     "Favored" : "Mesedetua",
     "Favor" : "Mesedea",
     "Not favored" : "Mesedetu gabe",
+    "Submitting fields…" : "Eremuak bidaltzen…",
     "Filter filenames…" : "Iragazi fitxategi-izenak..."
 },
 "nplurals=2; plural=(n != 1);");
