@@ -52,6 +52,7 @@ OC.L10N.register(
     "No picture for this day" : "Žádný obrázek pro tento den",
     "Picture taken on this day will show up here." : "Obrázek pořízený v tento den se zobrazí zde.",
     "More photos from this day" : "Více fotek z tohoto dne",
+    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepřiřazená fotka","%n nepřiřazené fotky","%n nepřiřazených fotek","%n nepřiřazené fotky"],
     "Favorite" : "Přidat do oblíbených",
     "Favorite image, open the full size \"{name}\" image" : "Zařadit obrázek mezi oblíbené, otevřít obrázek „{name}“ v plné velikosti",
@@ -85,6 +86,9 @@ OC.L10N.register(
     "Upload folder" : "Složka pro nahrávání",
     "Choose the folder where photos and albums are uploaded to." : "Zvolte složku do které nahrávat fotky a alba.",
     "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
+    "Select a date range" : "Vybrat datumové rozmezí",
+    "Date range" : "Datumové rozmezí",
+    "Select places" : "Vybrat místa",
     "Unselect all" : "Zrušit výběr všeho",
     "Add photos to this album" : "Přidat fotky do tohoto alba",
     "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
@@ -122,7 +126,7 @@ OC.L10N.register(
     "Add photos to this place" : "Přidat tomuto umístění nějaké fotky",
     "Cover photo for place {placeName}" : "Foto na obálku pro umístění {placeName}",
     "There is no place yet!" : "Zatím zde není žádné umístění!",
-    "Cover photo for shared album {albumName}." : "Foto na obálku sdíleného alba {albumName}.",
+    "Cover photo for shared album {albumName}" : "Foto na obálku sdíleného alba {albumName}",
     "Back to tags overview" : "Zpět na přehled štítků",
     "No photos with this tag yet" : "Zatím žádné fotky s tímto štítkem",
     "No tags yet" : "Zatím žádné štítky",
@@ -132,12 +136,13 @@ OC.L10N.register(
     "One of the source folders does not exist" : "Jedna ze zdrojových složek neexistuje",
     "Add to album" : "Přidat do alba",
     "Delete selection" : "Smazat výběr",
+    "Toggle filter" : "Vyp/zap. filtr",
     "No photos or videos in here" : "Nenacházejí se zde žádné fotky nebo videa",
     "Unassigned faces" : "Nepřiřazené obličeje",
-    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
     "Failed to fetch collection." : "Sbírku se nepodařilo stáhnout.",
     "Failed to fetch collections list." : "Nepodařilo se získat seznam sbírek.",
     "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
+    "Error fetching files" : "Chyba při získávání souborů",
     "All your media" : "Veškerá vaše média",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Sdílená alba",
@@ -148,12 +153,12 @@ OC.L10N.register(
     "{title}'s face" : "Obličej {title}",
     "{startDate} to {endDate}" : "{startDate} až {endDate}",
     "Details" : "Podrobnosti",
-    "Failed to rename {oldName} to {faceName}." : "Nepodařilo se přejmenovat {oldName} na {faceName}.",
-    "Failed to delete {faceName}." : "Nepodařilo se smazat {faceName}.",
-    "Failed to delete {fileId}." : "Nepodařilo se smazat {fileId}.",
-    "Failed to delete {fileName}." : "Nepodařilo se smazat {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Nepodařil se nastavit stav zařazení mezi oblíbené pro {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "Nepodařilo se přejmenovat {oldName} na {faceName}",
+    "Failed to delete {faceName}" : "Nepodařilo se smazat {faceName}",
+    "Failed to delete {fileId}" : "Nepodařilo se smazat {fileId}",
+    "Failed to delete {fileName}" : "Nepodařilo se smazat {fileName}",
+    "Failed to set favorite state for {fileId}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}",
+    "Failed to set favorite state for {fileName}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileName}",
     "Could not load photos folder" : "Nepodařilo se načíst složku s fotkami",
     "One of the source folders does not exists" : "Jedna ze zdrojových složek neexistuje",
     "Add" : "Přidat"
