@@ -34,56 +34,63 @@ OC.L10N.register(
     "Create new album" : "Neues Album erstellen",
     "New album" : "Neues Album",
     "_%n item_::_%n photos and videos_" : ["%n Stück","%n Fotos und Videos"],
+    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
+    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
     "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die Ihr Album bearbeiten können",
     "Search people or groups" : "Suchen nach Personen oder Gruppen",
     "No recommendations. Start typing." : "Keine Empfehlungen. Beginnen Sie mit der Eingabe.",
     "Group" : "Gruppe",
-    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
+    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden entfernen",
     "Copy the public link" : "Den öffentlichen Link kopieren",
     "Public link copied!" : "Öffentlicher Link kopiert!",
     "Copy public link" : "Öffentlichen Link kopieren",
     "Delete the public link" : "Den öffentlichen Link löschen",
     "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
     "Share via public link" : "Als öffentlichen Link teilen",
-    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
-    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
     "This collection does not exist" : "Diese Sammlung existiert nicht",
     "An error occurred" : "Es ist ein Fehler aufgetreten",
     "No picture for this day" : "Kein Bild für diesen Tag",
     "Picture taken on this day will show up here." : "Ein Bild, das an diesem Tag aufgenommen wurde, wird hier angezeigt.",
     "More photos from this day" : "Weitere Bilder von diesem Tag",
+    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
     "Favorite" : "Favorisieren",
-    "Select image {imageName}" : "Bild {imageName} auswählen",
     "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
     "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
+    "Select image {imageName}" : "Bild {imageName} auswählen",
     "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
-    "Go back" : "Zurückgehen",
     "Back to {folder}" : "Zurück zu {folder}",
+    "Go back" : "Zurückgehen",
     "Share this folder" : "Diesen Ordner teilen",
     "Dates" : "Daten",
     "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
     "Jump to {date}" : "Zu {date} springen",
     "Add to {destination}" : "Hinzufügen zu {destination}",
+    "The destination folder is owned by {owner}" : "Der Zielordner gehört {owner}",
     "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
     "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
     "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
     "Delete source directory" : "Quellverzeichnis löschen",
+    "Pick folder" : "Ordner auswählen",
+    "Select a source folder for your media" : "Quellordner für Ihre Medien wählen",
     "All folders" : "Alle Ordner",
     "Add a Photos source for the timelines" : "In Fotos eine Quelle für die Zeitleisten hinzufügen",
     "Add folder" : "Ordner hinzufügen",
-    "Select a source folder for your media" : "Quellordner für Ihre Medien wählen",
+    "Select the default upload location for your media" : "Standardspeicherort für Ihre hochgeladenen Medien auswählen",
     "Home" : "Startseite",
     "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
     "Choose a different folder" : "Anderen Ordner wählen",
-    "Select the default upload location for your media" : "Standardspeicherort für Ihre hochgeladenen Medien auswählen",
     "View" : "Ansicht",
     "Media folders" : "Medienordner",
     "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
     "Upload folder" : "Hochladen-Ordner",
     "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
     "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
+    "Select a date range" : "Einen Datumsbereich auswählen",
+    "Date range" : "Datumsbereich",
+    "Select places" : "Orte wählen",
     "Unselect all" : "Auswahl aufheben",
+    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
     "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
     "Open actions menu" : "Aktionsmenü öffnen",
     "Edit album details" : "Albumdetails bearbeiten",
@@ -92,7 +99,6 @@ OC.L10N.register(
     "Download selected files" : "Ausgewählte Dateien herunterladen",
     "Remove selection from album" : "Auswahl aus Album entfernen",
     "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
-    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
     "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
     "Manage collaborators" : "Mitarbeitende verwalten",
     "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
@@ -113,29 +119,30 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe Ihrer Fotobibliothek einige Zeit dauern.",
     "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
     "This folder does not exist" : "Dieser Ordner existiert nicht",
-    "Loading folders …" : "Ordner werden geladen...",
+    "Loading folders …" : "Ordner werden geladen …",
     "No photos in here" : "Keine Fotos vorhanden",
     "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
     "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
     "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
     "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
     "There is no place yet!" : "Es gibt noch keinen Ort",
-    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
+    "Cover photo for shared album {albumName}" : "Titelbild für freigegebenes Album {albumName}",
     "Back to tags overview" : "Zurück zur Schlagwortübersicht",
     "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
     "No tags yet" : "Noch keine Schlagworte vorhanden",
     "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
     "Popular tags" : "Beliebte Schlagworte",
-    "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
-    "Add" : "Hinzufügen",
+    "All tags" : "Alle Schlagworte",
+    "One of the source folders does not exist" : "Einer der Quellordner existiert nicht",
     "Add to album" : "Zum Album hinzufügen",
     "Delete selection" : "Auswahl löschen",
-    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos",
+    "Toggle filter" : "Filter umschalten",
+    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos.",
     "Unassigned faces" : "Nicht zugewiesene Gesichter",
-    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
     "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
     "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
     "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
+    "Error fetching files" : "Fehler beim Abrufen der Dateien",
     "All your media" : "Alle Ihre Medien",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Geteilte Alben",
@@ -146,37 +153,14 @@ OC.L10N.register(
     "{title}'s face" : "{title}s Gesicht",
     "{startDate} to {endDate}" : "{startDate} bis {endDate}",
     "Details" : "Details",
-    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
-    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
-    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
-    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
-    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "{oldName} konnte nicht in {faceName} umbenannt werden.",
+    "Failed to delete {faceName}" : "{faceName} konnte nicht gelöscht werden",
+    "Failed to delete {fileId}" : "{fileId} konnte nicht gelöscht werden",
+    "Failed to delete {fileName}" : "{fileName} konnte nicht gelöscht werden",
+    "Failed to set favorite state for {fileId}" : "Favoritenstatus für {fileId} konnte nicht gesetzt werden",
+    "Failed to set favorite state for {fileName}" : "Favoritenstatus für {fileName} konnte nicht gesetzt werden",
     "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
-    "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen.",
-    "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende hinzufügen wechseln.",
-    "Create the album." : "Das Album erstellen.",
-    "Back to the new album form." : "Zurück zur neuen Albumform.",
-    "_Share with %n user_::_Share with %n users_" : ["Mit %n Nutzer teilen","Mit %n Nutzern teilen"],
-    "Search for collaborators" : "Suche nach Mitbearbeitenden",
-    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} zur Liste der Mitarbeitenden hinzufügen",
-    "No collaborators available" : "Keine Mitarbeitenden verfügbar",
-    "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
-    "The file is in the favorites" : "Die Datei befindet sich in den Favoriten",
-    "Open the \"{name}\" sub-directory" : "Öffne den Unterordner \"{name}\" ",
-    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
-    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
-    "Invalid location selected" : "Ungültigen Speicherort ausgewählt",
-    "Photos directory" : "Fotoverzeichnis",
-    "Add photos to the album" : "Fotos zum Album hinzufügen",
-    "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
-    "Shared albums" : "Geteilte Alben",
-    "Create a new album" : "Neues Album erstellen",
-    "Add selection to an album" : "Auswahl einem Album hinzufügen",
-    "Failed to create {albumName}." : "{albumName} konnte nicht erstellt werden.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} konnte nicht in {newAlbumName} umbenannt werden.",
-    "Choose a Photos source for the timelines" : "In Photos eine Quelle für die Zeitleisten auswählen",
-    "Media folder" : "Medienordner",
-    "The source folder does not exists" : "Quellordner existiert nicht"
+    "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
+    "Add" : "Hinzufügen"
 },
 "nplurals=2; plural=(n != 1);");
