@@ -34,6 +34,8 @@ OC.L10N.register(
     "Create new album" : "Створити новий альбом",
     "New album" : "Новий альбом",
     "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
+    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
+    "Failed to update album." : "Не вдалося оновити альбом.",
     "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
     "Search people or groups" : "Пошук людей або груп",
     "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
@@ -45,38 +47,39 @@ OC.L10N.register(
     "Delete the public link" : "Вилучити публічне посилання",
     "Create public link share" : "Створити посилання спільного доступу",
     "Share via public link" : "Поділіться через публічне посилання",
-    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
-    "Failed to update album." : "Не вдалося оновити альбом.",
     "This collection does not exist" : "Ця колекція не існує",
     "An error occurred" : "Виникла помилка",
     "No picture for this day" : "Відсутні зображення цього дня",
     "Picture taken on this day will show up here." : "Зображення, які було отримано цього дня, будуть показані тут.",
     "More photos from this day" : "Більше світлин з цього дня",
+    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
-    "Favorite" : "До улюблених",
-    "Select image {imageName}" : "Виберіть зображення {imageName}",
+    "Favorite" : "Із зірочкою",
     "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
     "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
+    "Select image {imageName}" : "Виберіть зображення {imageName}",
     "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
-    "Go back" : "Повернутися назад",
     "Back to {folder}" : "Повернутися до каталогу {folder}",
+    "Go back" : "Повернутися назад",
     "Share this folder" : "Надати спільний доступ до каталогу",
     "Dates" : "Дати",
     "Jump to specific date in list" : "Перейти до певної дати зі списку",
     "Jump to {date}" : "Перейти до {date}",
     "Add to {destination}" : "Додати до {destination}",
+    "The destination folder is owned by {owner}" : "Власником каталогу призначення є {owner}",
     "There are no photos or videos yet!" : "Ще немає фото чи відео!",
     "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
     "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
     "Delete source directory" : "Вилучити каталог джерела",
+    "Pick folder" : "Вибрати каталог",
+    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
     "All folders" : "Усі каталоги",
     "Add a Photos source for the timelines" : "Додати джерело світлин до хронології",
     "Add folder" : "Додати теку",
-    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
+    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "Home" : "Домівка",
     "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
     "Choose a different folder" : "Виберіть інший каталог",
-    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "View" : "Перегляд",
     "Media folders" : "Каталоги з мультимедійним вмістом",
     "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
@@ -84,6 +87,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
     "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
     "Unselect all" : "Зняти вибір",
+    "Add photos to this album" : "Додайте фотографії до цього альбому",
     "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
     "Open actions menu" : "Відкрити меню дій",
     "Edit album details" : "Редагувати деталі альбому",
@@ -92,17 +96,16 @@ OC.L10N.register(
     "Download selected files" : "Звантажити вибрані файли",
     "Remove selection from album" : "Вилучити виділення з альбому",
     "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
-    "Add photos to this album" : "Додайте фотографії до цього альбому",
     "Add photos to {albumName}" : "Додати світлини до {albumName}",
     "Manage collaborators" : "Керуйте співавторами",
     "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
     "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
     "There is no album yet!" : "Альбоми поки відсутні",
-    "This person could not be found" : "Цю людину не вдалося знайти",
+    "This person could not be found" : "Не вдалося знайти людину",
     "Rename person" : "Перейменувати особу",
-    "Merge with different person" : "Злитися з іншою людиною",
+    "Merge with different person" : "Об'єднати з даними іншої особи",
     "Download selected photos" : "Звантажити вибрані світлини",
-    "Remove from favorites" : "Вилучено з улюбленого",
+    "Remove from favorites" : "Прибрати зірочку",
     "Remove person" : "Вилучити особу",
     "Name of this person" : "Ім'я цієї людини",
     "Save." : "Зберегти.",
@@ -120,22 +123,22 @@ OC.L10N.register(
     "Add photos to this place" : "Додайте фотографії до цього місця",
     "Cover photo for place {placeName}" : "Обкладинка для місця {placeName}",
     "There is no place yet!" : "Місця ще немає!",
-    "Cover photo for shared album {albumName}." : "Обкладинка для спільного альбому {albumName}.",
+    "Cover photo for shared album {albumName}" : "Обкладинка для спільного альбому {albumName}",
     "Back to tags overview" : "Назад до огляду міток",
     "No photos with this tag yet" : "Світлини з такою міткою відсутні",
     "No tags yet" : "Ще немає міток",
     "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
     "Popular tags" : "Популярні мітки",
-    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
-    "Add" : "Додати",
+    "All tags" : "Всі мітки",
+    "One of the source folders does not exist" : "Один із каталогів призначення відсутній",
     "Add to album" : "Додати в альбом",
     "Delete selection" : "Вилучити виділення",
     "No photos or videos in here" : "Тут немає фотографій та відео",
     "Unassigned faces" : "Неідентифіковані обличчя",
-    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
     "Failed to fetch collection." : "Не вдалося отримати колекцію.",
     "Failed to fetch collections list." : "Не вдалося отримати список колекцій.",
     "Failed to fetch faces list." : "Не вдалося отримати список зображень облич.",
+    "Error fetching files" : "Помилка під час отримання файлів",
     "All your media" : "Усі ваші зображення та відео",
     "Album {title}" : "Альбом {title}",
     "Shared Albums" : "Спільні альбоми",
@@ -146,37 +149,14 @@ OC.L10N.register(
     "{title}'s face" : "обличчя {title}",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Деталі",
-    "Failed to rename {oldName} to {faceName}." : "Не вдалося перейменувати {oldName} на {faceName}.",
-    "Failed to delete {faceName}." : "Не вдалося вилучити {faceName}.",
-    "Failed to delete {fileId}." : "Не вдалося вилучити {fileId}.",
-    "Failed to delete {fileName}." : "Не вдалося вилучити {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Не вдалося встановити улюблений стан для {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Не вдалося встановити улюблений стан для {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "Не вдалося перейменувати {oldName} у {faceName}",
+    "Failed to delete {faceName}" : "Не вдалося вилучити {faceName}",
+    "Failed to delete {fileId}" : "Не вдалося вилучити {fileId}",
+    "Failed to delete {fileName}" : "Не вдалося вилучити {fileName}",
+    "Failed to set favorite state for {fileId}" : "Не вдалося додати зірочку до {fileId}",
+    "Failed to set favorite state for {fileName}" : "Не вдалося додати зірочку до {fileName}",
     "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
-    "Go back to the previous view." : "Повернутися до попереднього перегляду.",
-    "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
-    "Create the album." : "Створіть альбом.",
-    "Back to the new album form." : "Повернутися до форми нового альбому.",
-    "_Share with %n user_::_Share with %n users_" : ["Поділіться з %n користувачем","Поділіться з %n користувачами","Поділіться з %n користувачами","Поділіться з %n користувачами"],
-    "Search for collaborators" : "Пошук співавторів",
-    "Add {collaboratorLabel} to the collaborators list" : "Додайте {collaboratorLabel} до списку співавторів",
-    "No collaborators available" : "Співавторів немає",
-    "Failed to fetch album." : "Не вдалося отримати альбом.",
-    "The file is in the favorites" : "Файл знаходиться в обраному",
-    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
-    "Default Photos upload and Albums location" : "Типове місце завантажених світлин та альбомів",
-    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
-    "Invalid location selected" : "Вибрано недійсне місце розташування",
-    "Photos directory" : "Каталог фотографій",
-    "Add photos to the album" : "Додайте фотографії в альбом",
-    "Failed to fetch albums list." : "Не вдалося отримати список альбомів.",
-    "Shared albums" : "Альбоми із спільним доступом",
-    "Create a new album" : "Створіть новий альбом",
-    "Add selection to an album" : "Додайте виділене в альбом",
-    "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}.",
-    "Choose a Photos source for the timelines" : "Виберіть джерело світлин для хронології",
-    "Media folder" : "Каталог для світлин чи відеозаписів",
-    "The source folder does not exists" : "Каталог джерела відсутній"
+    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
+    "Add" : "Додати"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
