@@ -32,8 +32,8 @@ OC.L10N.register(
     "You changed your email address" : "Você alterou o seu endereço de e-mail",
     "Your email address was changed by an administrator" : "O seu endereço de e-mail foi alterado por um administrador",
     "Security" : "Segurança",
-    "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois factores (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois factores (%1$s)",
+    "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois fatores (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois fatores (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
     "Settings" : "Configurações",
     "Could not remove app." : "Não foi possível remover a aplicação",
@@ -49,7 +49,7 @@ OC.L10N.register(
     "Invalid SMTP password." : "Senha de SMTP inválida.",
     "Email setting test" : "Teste definições de email",
     "Well done, %s!" : "Muito bem, %s!",
-    "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correcta.",
+    "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correta.",
     "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
     "Invalid account" : "Conta inválida",
@@ -96,13 +96,13 @@ OC.L10N.register(
     "Verifying" : "A verificar",
     "Internet connectivity" : "Conetividade da Internet",
     "Internet connectivity is disabled in configuration file." : "A conetividade da Internet está desativada no ficheiro de configuração.",
-    "Disabled" : "Desactivado",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
+    "Disabled" : "Desativado",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A ativação desta função é altamente recomendada.",
     "Supported" : "Suportado",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transação \"READ COMMITTED\" ativado. Isto pode causar problemas quando várias ações são executadas em paralelo.",
     "Profile information" : "Informação de perfil",
     "Nextcloud settings" : "Definições Nextcloud",
     "Enable" : "Ativar",
@@ -118,88 +118,94 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
     "Limit to groups" : "Limitado a grupos",
     "Save changes" : "Guardar alterações",
+    "Update to {update}" : "Atualizar para {update}",
     "Remove" : "Remover",
     "Featured" : "Destacado",
+    "Disable all" : "Desativar todos",
+    "Download and enable all" : "Transferir e ativar tudo",
     "All apps are up-to-date." : "Todas as aplicações estão atualizadas",
     "Name" : "Nome",
     "Version" : "Versão",
     "Level" : "Nível",
-    "Actions" : "Acções",
+    "Actions" : "Ações",
     "Results from other categories" : "Resultados de outras categorias",
     "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
-    "Disable all" : "Desativar todos",
-    "Download and enable all" : "Transferir e ativar tudo",
     "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
+    "Group name" : "Nome do grupo",
     "Loading" : "A carregar",
     "Type" : "Tipo",
+    "Learn more" : "Conheça melhor",
+    "Confirm" : "Confirmar",
+    "Cancel" : "Cancelar",
     "Description" : "Descrição",
-    "Details" : "Detalhes",
-    "All" : "Todos",
-    "No results" : "Sem resultados",
-    "Update to {version}" : "Actualizar para {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
-    "Categories" : "Categorias",
-    "Resources" : "Recursos",
-    "Documentation" : "Documentação",
-    "Report a bug" : "Reportar um erro",
-    "Request feature" : "Pedir funcionalidade",
-    "Ask questions or discuss" : "Perguntar ou discutir",
-    "Rate" : "Classificar",
     "View in store" : "Ver na loja",
     "Visit website" : "Visitar o website",
     "Admin documentation" : "Documentação do Administrador",
     "Developer documentation" : "Documentação de Programador",
+    "Details" : "Detalhes",
+    "All" : "Todos",
+    "No results" : "Sem resultados",
+    "Update to {version}" : "Atualizar para {version}",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
+    "Author" : "Autor",
+    "Categories" : "Categorias",
+    "Resources" : "Recursos",
+    "Documentation" : "Documentação",
+    "Interact" : "Interagir",
+    "Report a bug" : "Reportar um erro",
+    "Request feature" : "Pedir funcionalidade",
+    "Ask questions or discuss" : "Perguntar ou discutir",
+    "Rate" : "Classificar",
     "Changelog" : "Registo de alterações",
-    "Device settings" : "Definições de dispositivo",
-    "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
-    "Rename" : "Renomear",
-    "Revoke" : "Revogar",
-    "Wipe device" : "Apagar dispositivo",
     "Google Chrome for Android" : "Google Chrome para Android",
     "Sync client" : "Sincronizar cliente",
     "This session" : "Esta sessão",
     "{client} - {version} ({system})" : "{client} - {version} ({system})",
     "{client} - {version}" : "{client} - {version}",
+    "Device settings" : "Definições de dispositivo",
+    "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
+    "Rename" : "Renomear",
+    "Revoke" : "Revogar",
+    "Wipe device" : "Apagar dispositivo",
     "Device" : "Dispositivo",
     "Last activity" : "Última atividade",
     "Devices & sessions" : "Sessões e dispositivos",
     "Web, desktop and mobile clients currently logged in to your account." : "Os clientes da Web, de PC e móveis estão atualmente autenticados na sua conta.",
+    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
     "App name" : "Nome da App",
     "Create new app password" : "Criar nova palavra-passe de aplicação",
-    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
     "Login" : "Iniciar Sessão",
     "Password" : "Palavra-passe",
     "Profile" : "Perfil",
     "Server-side encryption" : "Atualizar App",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser activo quando necessário.",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser ativo quando necessário.",
     "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
+    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
+    "Enable encryption" : "Ativar a encriptação",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A cifra por si só não garante a segurança do sistema. Por favor consulte a documentação para mais detalhes sobre a aplicação de cifra e os casos de uso suportados.",
     "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
     "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
-    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
-    "Cancel" : "Cancelar",
-    "Confirm" : "Confirmar",
     "Submit" : "Submeter",
     "Current password" : "Palavra-passe atual",
     "New password" : "Nova palavra-passe",
     "Change password" : "Alterar palavra-passe",
-    "Your profile picture" : "Imagem de perfil",
-    "Upload profile picture" : "Atualização de imagem de perfil",
-    "Choose profile picture from Files" : "Escolher a imagem de perfil em Ficheiros",
-    "Remove profile picture" : "Remover imagem de perfil",
-    "Picture provided by original account" : "Imagem fornecida pela conta original",
-    "Set as profile picture" : "Definir como imagem de perfil",
     "Choose your profile picture" : "Escolher imagem de perfil",
     "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
     "Error setting profile picture" : "Erro a definir imagem de perfil",
     "Error cropping profile picture" : "Erro a cortar imagem de perfil",
     "Error saving profile picture" : "Erro a guardar imagem de perfil",
     "Error removing profile picture" : "Erro a remover imagem de perfil",
+    "Your profile picture" : "Imagem de perfil",
+    "Upload profile picture" : "Atualização de imagem de perfil",
+    "Choose profile picture from Files" : "Escolher a imagem de perfil em Ficheiros",
+    "Remove profile picture" : "Remover imagem de perfil",
+    "Picture provided by original account" : "Imagem fornecida pela conta original",
+    "Set as profile picture" : "Definir como imagem de perfil",
     "You are a member of the following groups:" : "Membro dos seguintes grupos:",
     "Your full name" : "Nome completo",
     "Email options" : "Opções de correio eletrónico",
@@ -227,12 +233,11 @@ OC.L10N.register(
     "Done" : "Concluído",
     "Edit" : "Editar",
     "Visibility" : "Visibilidade",
-    "Show last login" : "Mostrar último login",
+    "Show last login" : "Mostrar último início de sessão",
     "Send email" : "Enviar email",
     "Default quota" : "Quota padrão",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
     "Admins" : "Administrador",
-    "Group name" : "Nome do grupo",
     "Sending…" : "A enviar...",
     "Email sent" : "Mensagem de correio eletrónico enviada",
     "Location" : "Localização",
@@ -246,15 +251,16 @@ OC.L10N.register(
     "Website" : "Website",
     "Your apps" : "As suas apps",
     "Disabled apps" : "Apps desativadas",
-    "Updates" : "Actualizações",
+    "Updates" : "Atualizações",
     "App bundles" : "Pacotes de apps",
+    "Featured apps" : "Aplicações principais",
     "Hide" : "Ocultar",
     "Download and enable" : "Transferir e ativar",
     "Disable" : "Desativar",
     "The app will be downloaded from the App Store" : "A aplicação será transferida da App Store",
     "Unknown" : "Desconhecido",
     "Never" : "Nunca",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A app foi activada mas necessita ser actualizada. Irá ser redireccionado para a página de actualização em 5 segundos.",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada mas necessita ser atualizada. Irá ser redirecionado para a página de atualização em 5 segundos.",
     "Do you really want to wipe your data from this device?" : "Tem a certeza que deseja apagar os dados deste dispositivo?",
     "Confirm wipe" : "Confirmação de limpeza",
     "Error" : "Erro",
@@ -281,18 +287,9 @@ OC.L10N.register(
     "Check out our blog" : "Veja o nosso blog",
     "Subscribe to our newsletter" : "Subscreva as nossas notícias",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
-    "No user supplied" : "Nenhum utilizador especificado",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor introduza uma senha administrativa de recuperação ou todos os dados de utilizador serão perdidos.",
-    "Invalid user" : "Utilizador inválido",
-    "Your username is: %s" : "O seu utilizador é: %s",
-    "Exclude groups from sharing" : "Excluir grupos das partilhas",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderão receber partilhas, mas não poderão iniciá-las.",
-    "Username" : "Nome de utilizador",
     "Your biography" : "Biografia",
+    "Username" : "Nome de utilizador",
     "User backend" : "Backend do utilizador",
-    "Show user backend" : "Mostrar interface do utilizador",
-    "Active users" : "Utilizadores activos",
-    "SMTP Username" : "Nome de utilizador SMTP",
     "Follow us on Twitter" : "Siga-nos no Twitter"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
