@@ -104,7 +104,6 @@ OC.L10N.register(
     "Set your password" : "Ställ in ditt lösenord",
     "Go to %s" : "Gå till %s",
     "Install Client" : "Installera Klient",
-    "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
     "Apps" : "Appar",
     "Personal" : "Privat",
     "Administration" : "Administration",
@@ -177,6 +176,8 @@ OC.L10N.register(
     "Old server-side-encryption" : "Gammal serverkryptering",
     "Disabled" : "Inaktiverad",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
+    "Logging level" : "Loggnivå",
+    "Logging level configured correctly." : "Loggnivå är korrekt konfigurerad.",
     "Maintenance window start" : "Underhållsfönster startar",
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Servern har ingen konfigurerad starttid för underhållsfönster. Detta innebär att resurskrävande dagliga bakgrundsjobb också kommer att köras under din huvudsakliga användningstid. Vi rekommenderar att du ställer in det till en tid med låg användning, så att användarna påverkas mindre av belastningen som orsakas av dessa tunga uppgifter.",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Underhållsfönstret för att utföra tunga bakgrundsjobb är mellan {start}:00 UTC och {end}:00 UTC",
@@ -303,6 +304,15 @@ OC.L10N.register(
     "No apps found for your version" : "Inga appar funna för din version",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en uppdatering tillgänglig","%n appar har en uppdatering tillgänglig"],
     "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
+    "Failed to load groups" : "Kunde inte läsa in grupper",
+    "Failed to create group" : "Det gick inte att skapa gruppen",
+    "Creating group…" : "Skapar grupp...",
+    "Create group" : "Skapa grupp",
+    "Group name" : "Gruppnamn",
+    "Please enter a valid group name" : "Ange ett giltigt gruppnamn",
+    "Search groups…" : "Sök grupper…",
+    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Grupplista. Denna lista är inte fullständigt inläst av prestandaskäl. Grupperna kommer att laddas när du navigerar eller söker i listan.",
+    "Loading groups…" : "Hämtar grupper...",
     "Nothing to show" : "Inget att visa",
     "Could not load section content from app store." : "Det gick inte att ladda avsnittsinnehåll från app store.",
     "Loading" : "Läser in",
@@ -504,6 +514,7 @@ OC.L10N.register(
     "Set line manager" : "Ange linjechef",
     "Account name will be autogenerated" : "Kontonamn kommer att autogenereras",
     "Account name (required)" : "Kontonamn (obligatoriskt)",
+    "Failed to search groups" : "Kunde inte söka efter grupper",
     "New account" : "Nytt konto",
     "Display name" : "Visningsnamn",
     "Either password or email is required" : "Antingen lösenord eller e-post krävs",
@@ -541,12 +552,15 @@ OC.L10N.register(
     "Remote wipe of devices" : "Fjärrensning av enheter",
     "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
     "Wiped {userid}'s devices" : "Rensade enheter för {userid}",
+    "Failed to load groups with details" : "Kunde inte läsa in grupper med detaljer",
     "Failed to update line manager" : "Kunde inte uppdatera linjechef",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fullständig radering av konto för {userid} inklusive alla personliga filer, appdata etc.",
     "Account deletion" : "Radering av konto",
     "Delete {userid}'s account" : "Ta bort konto för {userid}",
     "Display name was successfully changed" : "Visningsnamnet har ändrats",
+    "Password can't be empty" : "Lösenord får inte vara tomt",
     "Password was successfully changed" : "Lösenordet har ändrats",
+    "Email can't be empty" : "E-post får inte vara tomt",
     "Email was successfully changed" : "E-postadressen har ändrats",
     "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
     "Loading account …" : "Laddar konto ...",
@@ -597,12 +611,7 @@ OC.L10N.register(
     "All accounts" : "Alla konton",
     "Admins" : "Administratörer",
     "Account group: {group}" : "Kontogrupp: {group}",
-    "Failed to create group" : "Det gick inte att skapa gruppen",
     "Account management" : "Kontohantering",
-    "Creating group…" : "Skapar grupp...",
-    "Create group" : "Skapa grupp",
-    "Group name" : "Gruppnamn",
-    "Please enter a valid group name" : "Ange ett giltigt gruppnamn",
     "Sending…" : "Skickar...",
     "Email sent" : "E-post skickad",
     "Location" : "Plats",
@@ -699,6 +708,7 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
+    "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
     "Missing optional index \"%s\" in table \"%s\"." : "Saknar valfri index \"%s\" i tabellen \"%s\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
     "File locking" : "Fillåsning",
