@@ -20,10 +20,10 @@ OC.L10N.register(
     "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
     "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähettämisen",
     "No file uploaded" : "Ei tiedostoa lähetetty",
-    "Failed to delete folder: \"%1$s\", error: %2$s" : "Kansion poistaminen epäonnistui: \"%1$s\", virhe: %2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Käytät jo mukautettua teemaa. Teemoitussovelluksen asetukset saatetaan ohittaa.",
     "Theming" : "Teema",
     "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
+    "PHP Imagick module" : "PHP:n Imagick-moduuli",
     "Dark theme with high contrast mode" : "Tumma teema korkean kontrastin tilalla",
     "Enable dark high contrast mode" : "Ota käyttöön tumma korkean kontrastin tila",
     "Similar to the high contrast mode, but with dark colours." : "Samankaltainen korkean kontrastin tilan kanssa, mutta tummien värien kera.",
@@ -45,16 +45,10 @@ OC.L10N.register(
     "Legal notice" : "Lainopillinen huomautus",
     "Privacy policy" : "Yksityisyyskäytäntö",
     "Adjust the Nextcloud theme" : "Mukauta Nextcloudin teemaa",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teeman avulla voit helposti kustomoida web-käyttöliittymän ja tuettujen sovelluksien ulkonäköä ja tuntumaa. Teema näkyy kaikille käyttäjille.",
-    "Advanced options" : "Lisävalinnat",
     "Name" : "Nimi",
     "Web link" : "Verkkolinkki",
     "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
     "Slogan" : "Slogani",
-    "Color" : "Väri",
-    "Logo" : "Logo",
-    "Upload new logo" : "Lähetä uusi logo",
-    "Background and login image" : "Tausta- ja kirjautumiskuva",
     "Legal notice link" : "Lainopillisen huomautuksen linkki",
     "Privacy policy link" : "Yksityisyyskäytännön linkki",
     "Header logo" : "Otsakelogo",
@@ -63,29 +57,38 @@ OC.L10N.register(
     "Upload new favicon" : "Lähetä uusi favicon",
     "User settings" : "Käyttäjäasetukset",
     "Disable user theming" : "Poista käyttäjäteemoitus käytöstä",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Vaikka voit mukauttaa instanssia, käyttäjät voivat vaihtaa taustakuvaansa ja värejään. Jos haluat pakottaa mukautukset käyttäjille, ota tämä asetus käyttöön.",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teeman avulla voit helposti kustomoida web-käyttöliittymän ja tuettujen sovelluksien ulkonäköä ja tuntumaa. Teema näkyy kaikille käyttäjille.",
+    "Upload new logo" : "Lähetä uusi logo",
+    "Logo" : "Logo",
+    "Upload new background and login image" : "Lähetä uusi taustakuva ja kirjautumissivun kuva",
+    "Background and login image" : "Tausta- ja kirjautumiskuva",
+    "Advanced options" : "Lisävalinnat",
+    "Appearance and accessibility settings" : "Ulkoasun ja saavutettavuuden asetukset",
+    "Customization has been disabled by your administrator" : "Mukauttaminen on poistettu käytöstä ylläpitäjän toimesta",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Disable all keyboard shortcuts" : "Poista käytöstä kaikki pikanäppäimet",
-    "Background" : "Tausta",
-    "Customization has been disabled by your administrator" : "Mukauttaminen on poistettu käytöstä ylläpitäjän toimesta",
-    "Set a custom background" : "Aseta mukautettu tausta",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Saavutettavuus on erittäin tärkeää meille. Seuraamme verkkostandardeja ja varmistamme, että kaikki on käytettävissä ilman hiirtä sekä avustavien ohjelmistojen kuten ruudunlukijoiden avulla. Pyrimme olemaan yhteensopivia {guidelines}Web Content Accessibility Guidelines{linkend} -ohjeistuksen version 2.1 AA-tason kanssa, suuren kontrastin teemalla pyrimme jopa AAA-tasoon.",
-    "Pick from Files" : "Valitse tiedostoista",
-    "Default image" : "Oletuskuva",
-    "Custom color" : "Mukautettu väri",
+    "Move up" : "Siirrä ylös",
+    "Move down" : "Siirrä alas",
+    "Select a background from your files" : "Valitse taustakuva tiedostoista",
+    "Select background" : "Valitse tausta",
+    "No background has been selected" : "Taustaa ei ole valittu",
+    "Custom background" : "Mukautettu taustakuva",
     "Plain background" : "Yksinkertainen tausta",
-    "Insert from {productName}" : "Aseta kohteesta {productName}",
+    "Default background" : "Oletustausta",
     "Theme selection is enforced" : "Teemavalinta on pakotettu",
+    "Navigation bar settings" : "Navigointipalkin asetukset",
+    "Default app" : "Oletussovellus",
+    "Use custom default app" : "Käytä mukautettua oletussovellusta",
+    "Select a custom color" : "Valitse mukautettu väri",
     "Reset to default" : "Palauta oletukseksi",
     "Upload" : "Lähetä",
     "Remove background image" : "Poista taustakuva",
-    "Loading preview…" : "Ladataan esikatselua…",
-    "Admin" : "Ylläpito",
-    "Name cannot be empty" : "Nimi ei voi olla tyhjä",
-    "Open documentation" : "Avaa dokumentaatio",
-    "https://…" : "https://…",
-    "Login image" : "Kirjautumissivun kuva",
-    "Upload new login background" : "Lähetä uusi kirjautumissivun taustakuva",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Asenna Imagemagick PHP-lisäosa SVG-kuvatuella generoidaksesi automaattisesti logoon ja väriin perustuvat suosikkikuvakkeet.",
-    "Error uploading the file" : "Virhe tiedostoa lähettäessä"
+    "Color" : "Väri",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Saavutettavuus on erittäin tärkeää meille. Seuraamme verkkostandardeja ja varmistamme, että kaikki on käytettävissä ilman hiirtä sekä avustavien ohjelmistojen kuten ruudunlukijoiden avulla. Pyrimme olemaan yhteensopivia {guidelines}Web Content Accessibility Guidelines{linkend} -ohjeistuksen version 2.1 AA-tason kanssa, suuren kontrastin teemalla pyrimme jopa AAA-tasoon.",
+    "Background" : "Tausta",
+    "Set a custom background" : "Aseta mukautettu tausta",
+    "Change color" : "Vaihda väriä",
+    "No background" : "Ei taustakuvaa"
 },
 "nplurals=2; plural=(n != 1);");
