@@ -1,51 +1,26 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Juan Pablo Villafáñez <jvillafanez@solidgear.es>
- * @author Marc Hefter <marchefter@march42.net>
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Philipp Staiger <philipp@staiger.it>
- * @author Roger Szabo <roger.szabo@web.de>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Victor Dubiniuk <dubiniuk@owncloud.com>
- * @author Vincent Petry <vincent@nextcloud.com>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program. If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 namespace OCA\User_LDAP\User;
 
-use Exception;
+use InvalidArgumentException;
 use OC\Accounts\AccountManager;
 use OCA\User_LDAP\Access;
 use OCA\User_LDAP\Connection;
 use OCA\User_LDAP\Exceptions\AttributeNotSet;
 use OCA\User_LDAP\FilesystemHelper;
+use OCA\User_LDAP\Service\BirthdateParserService;
+use OCP\Accounts\IAccountManager;
+use OCP\Accounts\PropertyDoesNotExistException;
 use OCP\IAvatarManager;
 use OCP\IConfig;
-use OCP\ILogger;
 use OCP\Image;
 use OCP\IUser;
 use OCP\IUserManager;
-use OCP\Accounts\IAccountManager;
-use OCP\Accounts\PropertyDoesNotExistException;
 use OCP\Notification\IManager as INotificationManager;
 use OCP\Server;
 use Psr\Log\LoggerInterface;
@@ -109,6 +84,8 @@ class User {
 	 */
 	protected $avatarImage;
 
+	protected BirthdateParserService $birthdateParser;
+
 	/**
 	 * DB config keys for user preferences
 	 */
@@ -142,6 +119,7 @@ class User {
 		$this->avatarManager = $avatarManager;
 		$this->userManager = $userManager;
 		$this->notificationManager = $notificationManager;
+		$this->birthdateParser = new BirthdateParserService();
 
 		\OCP\Util::connectHook('OC_User', 'post_login', $this, 'handlePasswordExpiry');
 	}
@@ -158,7 +136,7 @@ class User {
 			return;
 		}
 		$this->config->setUserValue($this->getUsername(), 'user_ldap', 'isDeleted', '1');
-		$this->config->setUserValue($this->getUsername(), 'user_ldap', 'foundDeleted', (string)time());
+		$this->config->setUserValue($this->getUsername(), 'user_ldap', 'foundDeleted', (string) time());
 	}
 
 	/**
@@ -181,11 +159,11 @@ class User {
 		$displayName = $displayName2 = '';
 		$attr = strtolower($this->connection->ldapUserDisplayName);
 		if (isset($ldapEntry[$attr])) {
-			$displayName = (string)$ldapEntry[$attr][0];
+			$displayName = (string) $ldapEntry[$attr][0];
 		}
 		$attr = strtolower($this->connection->ldapUserDisplayName2);
 		if (isset($ldapEntry[$attr])) {
-			$displayName2 = (string)$ldapEntry[$attr][0];
+			$displayName2 = (string) $ldapEntry[$attr][0];
 		}
 		if ($displayName !== '') {
 			$this->composeAndStoreDisplayName($displayName, $displayName2);
@@ -214,7 +192,7 @@ class User {
 		}
 
 		//homePath
-		if (strpos($this->connection->homeFolderNamingRule, 'attr:') === 0) {
+		if (str_starts_with($this->connection->homeFolderNamingRule, 'attr:')) {
 			$attr = strtolower(substr($this->connection->homeFolderNamingRule, strlen('attr:')));
 			if (isset($ldapEntry[$attr])) {
 				$this->access->cacheUserHome(
@@ -246,105 +224,117 @@ class User {
 			($profileCached === null) && // no cache or TTL not expired
 			!$this->wasRefreshed('profile')) {
 			// check current data
-			$profileValues = array();
+			$profileValues = [];
 			//User Profile Field - Phone number
 			$attr = strtolower($this->connection->ldapAttributePhone);
 			if (!empty($attr)) { // attribute configured
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_PHONE]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - website
 			$attr = strtolower($this->connection->ldapAttributeWebsite);
 			if (isset($ldapEntry[$attr])) {
-				$cutPosition = strpos($ldapEntry[$attr][0]," ");
+				$cutPosition = strpos($ldapEntry[$attr][0], ' ');
 				if ($cutPosition) {
 					// drop appended label
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_WEBSITE]
-						= substr($ldapEntry[$attr][0],0,$cutPosition);
+						= substr($ldapEntry[$attr][0], 0, $cutPosition);
 				} else {
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_WEBSITE]
 						= $ldapEntry[$attr][0];
 				}
 			} elseif (!empty($attr)) {	// configured, but not defined
-				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_WEBSITE] = "";
+				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_WEBSITE] = '';
 			}
 			//User Profile Field - Address
 			$attr = strtolower($this->connection->ldapAttributeAddress);
 			if (isset($ldapEntry[$attr])) {
-				if (str_contains($ldapEntry[$attr][0],'$')) {
+				if (str_contains($ldapEntry[$attr][0], '$')) {
 					// basic format conversion from postalAddress syntax to commata delimited
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ADDRESS]
-						= str_replace('$', ", ", $ldapEntry[$attr][0]);
+						= str_replace('$', ', ', $ldapEntry[$attr][0]);
 				} else {
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ADDRESS]
 						= $ldapEntry[$attr][0];
 				}
 			} elseif (!empty($attr)) {	// configured, but not defined
-				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ADDRESS] = "";
+				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ADDRESS] = '';
 			}
 			//User Profile Field - Twitter
 			$attr = strtolower($this->connection->ldapAttributeTwitter);
 			if (!empty($attr)) {
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_TWITTER]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - fediverse
 			$attr = strtolower($this->connection->ldapAttributeFediverse);
 			if (!empty($attr)) {
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_FEDIVERSE]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - organisation
 			$attr = strtolower($this->connection->ldapAttributeOrganisation);
 			if (!empty($attr)) {
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ORGANISATION]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - role
 			$attr = strtolower($this->connection->ldapAttributeRole);
 			if (!empty($attr)) {
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_ROLE]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - headline
 			$attr = strtolower($this->connection->ldapAttributeHeadline);
 			if (!empty($attr)) {
 				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_HEADLINE]
-					= $ldapEntry[$attr][0] ?? "";
+					= $ldapEntry[$attr][0] ?? '';
 			}
 			//User Profile Field - biography
 			$attr = strtolower($this->connection->ldapAttributeBiography);
 			if (isset($ldapEntry[$attr])) {
-				if (str_contains($ldapEntry[$attr][0],'\r')) {
+				if (str_contains($ldapEntry[$attr][0], '\r')) {
 					// convert line endings
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_BIOGRAPHY]
-						= str_replace(array("\r\n","\r"), "\n", $ldapEntry[$attr][0]);
+						= str_replace(["\r\n","\r"], "\n", $ldapEntry[$attr][0]);
 				} else {
 					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_BIOGRAPHY]
 						= $ldapEntry[$attr][0];
 				}
 			} elseif (!empty($attr)) {	// configured, but not defined
-				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_BIOGRAPHY] = "";
+				$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_BIOGRAPHY] = '';
+			}
+			//User Profile Field - birthday
+			$attr = strtolower($this->connection->ldapAttributeBirthDate);
+			if (!empty($attr) && !empty($ldapEntry[$attr][0])) {
+				$value = $ldapEntry[$attr][0];
+				try {
+					$birthdate = $this->birthdateParser->parseBirthdate($value);
+					$profileValues[\OCP\Accounts\IAccountManager::PROPERTY_BIRTHDATE]
+						= $birthdate->format('Y-m-d');
+				} catch (InvalidArgumentException $e) {
+					// Invalid date -> just skip the property
+					$this->logger->info("Failed to parse user's birthdate from LDAP: $value", [
+						'exception' => $e,
+						'userId' => $username,
+					]);
+				}
 			}
 			// check for changed data and cache just for TTL checking
 			$checksum = hash('sha256', json_encode($profileValues));
-			$this->connection->writeToCache($cacheKey
-				, $checksum // write array to cache. is waste of cache space
+			$this->connection->writeToCache($cacheKey, $checksum // write array to cache. is waste of cache space
 				, null); // use ldapCacheTTL from configuration
 			// Update user profile
 			if ($this->config->getUserValue($username, 'user_ldap', 'lastProfileChecksum', null) !== $checksum) {
 				$this->config->setUserValue($username, 'user_ldap', 'lastProfileChecksum', $checksum);
 				$this->updateProfile($profileValues);
-				$this->logger->info("updated profile uid=$username"
-					, ['app' => 'user_ldap']);
+				$this->logger->info("updated profile uid=$username", ['app' => 'user_ldap']);
 			} else {
-				$this->logger->debug("profile data from LDAP unchanged"
-					, ['app' => 'user_ldap', 'uid' => $username]);
+				$this->logger->debug('profile data from LDAP unchanged', ['app' => 'user_ldap', 'uid' => $username]);
 			}
 			unset($attr);
 		} elseif ($profileCached !== null) { // message delayed, to declutter log
-			$this->logger->debug("skipping profile check, while cached data exist"
-				, ['app' => 'user_ldap', 'uid' => $username]);
+			$this->logger->debug('skipping profile check, while cached data exist', ['app' => 'user_ldap', 'uid' => $username]);
 		}
 
 		//Avatar
@@ -387,11 +377,11 @@ class User {
 	 * @throws \Exception
 	 */
 	public function getHomePath($valueFromLDAP = null) {
-		$path = (string)$valueFromLDAP;
+		$path = (string) $valueFromLDAP;
 		$attr = null;
 
 		if (is_null($valueFromLDAP)
-		   && strpos($this->access->connection->homeFolderNamingRule, 'attr:') === 0
+		   && str_starts_with($this->access->connection->homeFolderNamingRule, 'attr:')
 		   && $this->access->connection->homeFolderNamingRule !== 'attr:') {
 			$attr = substr($this->access->connection->homeFolderNamingRule, strlen('attr:'));
 			$homedir = $this->access->readAttribute($this->access->username2dn($this->getUsername()), $attr);
@@ -403,12 +393,12 @@ class User {
 		if ($path !== '') {
 			//if attribute's value is an absolute path take this, otherwise append it to data dir
 			//check for / at the beginning or pattern c:\ resp. c:/
-			if ('/' !== $path[0]
-			   && !(3 < strlen($path) && ctype_alpha($path[0])
-				   && $path[1] === ':' && ('\\' === $path[2] || '/' === $path[2]))
+			if ($path[0] !== '/'
+			   && !(strlen($path) > 3 && ctype_alpha($path[0])
+				   && $path[1] === ':' && ($path[2] === '\\' || $path[2] === '/'))
 			) {
 				$path = $this->config->getSystemValue('datadirectory',
-						\OC::$SERVERROOT.'/data') . '/' . $path;
+					\OC::$SERVERROOT.'/data') . '/' . $path;
 			}
 			//we need it to store it in the DB as well in case a user gets
 			//deleted so we can clean up afterwards
@@ -493,7 +483,7 @@ class User {
 	 * @return string the effective display name
 	 */
 	public function composeAndStoreDisplayName($displayName, $displayName2 = '') {
-		$displayName2 = (string)$displayName2;
+		$displayName2 = (string) $displayName2;
 		if ($displayName2 !== '') {
 			$displayName .= ' (' . $displayName2 . ')';
 		}
@@ -542,20 +532,20 @@ class User {
 		if ($this->wasRefreshed('email')) {
 			return;
 		}
-		$email = (string)$valueFromLDAP;
+		$email = (string) $valueFromLDAP;
 		if (is_null($valueFromLDAP)) {
 			$emailAttribute = $this->connection->ldapEmailAttribute;
 			if ($emailAttribute !== '') {
 				$aEmail = $this->access->readAttribute($this->dn, $emailAttribute);
 				if (is_array($aEmail) && (count($aEmail) > 0)) {
-					$email = (string)$aEmail[0];
+					$email = (string) $aEmail[0];
 				}
 			}
 		}
 		if ($email !== '') {
 			$user = $this->userManager->get($this->uid);
 			if (!is_null($user)) {
-				$currentEmail = (string)$user->getSystemEMailAddress();
+				$currentEmail = (string) $user->getSystemEMailAddress();
 				if ($currentEmail !== $email) {
 					$user->setEMailAddress($email);
 				}
@@ -580,7 +570,7 @@ class User {
 	 *
 	 * fetches the quota from LDAP and stores it as Nextcloud user value
 	 * @param ?string $valueFromLDAP the quota attribute's value can be passed,
-	 * to save the readAttribute request
+	 *                               to save the readAttribute request
 	 * @return void
 	 */
 	public function updateQuota($valueFromLDAP = null) {
@@ -630,7 +620,7 @@ class User {
 
 	/**
 	 * takes values from LDAP and stores it as Nextcloud user profile value
-	 * 
+	 *
 	 * @param array $profileValues associative array of property keys and values from LDAP
 	 */
 	private function updateProfile(array $profileValues): void {
@@ -650,7 +640,7 @@ class User {
 		$defaultScopes = array_merge(AccountManager::DEFAULT_SCOPES,
 			$this->config->getSystemValue('account_manager.default_property_scope', []));
 		// loop through the properties and handle them
-		foreach($profileValues as $property => $valueFromLDAP) {
+		foreach ($profileValues as $property => $valueFromLDAP) {
 			// check and update profile properties
 			$value = (is_array($valueFromLDAP) ? $valueFromLDAP[0] : $valueFromLDAP); // take ONLY the first value, if multiple values specified
 			try {
@@ -658,17 +648,15 @@ class User {
 				$currentValue = $accountProperty->getValue();
 				$scope = ($accountProperty->getScope() ? $accountProperty->getScope()
 					: $defaultScopes[$property]);
-			}
-			catch (PropertyDoesNotExistException $e) { // thrown at getProperty
+			} catch (PropertyDoesNotExistException $e) { // thrown at getProperty
 				$this->logger->error('property does not exist: '.$property
-					.' for uid='.$this->uid.''
-					, ['app' => 'user_ldap', 'exception' => $e]);
+					.' for uid='.$this->uid.'', ['app' => 'user_ldap', 'exception' => $e]);
 				$currentValue = '';
 				$scope = $defaultScopes[$property];
 			}
 			$verified = IAccountManager::VERIFIED; // trust the LDAP admin knew what he put there
 			if ($currentValue !== $value) {
-				$account->setProperty($property,$value,$scope,$verified);
+				$account->setProperty($property, $value, $scope, $verified);
 				$this->logger->debug('update user profile: '.$property.'='.$value
 					.' for uid='.$this->uid.'', ['app' => 'user_ldap']);
 			}
@@ -676,8 +664,7 @@ class User {
 		try {
 			$accountManager->updateAccount($account); // may throw InvalidArgumentException
 		} catch (\InvalidArgumentException $e) {
-			$this->logger->error('invalid data from LDAP: for uid='.$this->uid.''
-				, ['app' => 'user_ldap', 'func' => 'updateProfile'
+			$this->logger->error('invalid data from LDAP: for uid='.$this->uid.'', ['app' => 'user_ldap', 'func' => 'updateProfile'
 				, 'exception' => $e]);
 		}
 	}
@@ -695,9 +682,9 @@ class User {
 
 	/**
 	 * @brief attempts to get an image from LDAP and sets it as Nextcloud avatar
-	 * @return bool
+	 * @return bool true when the avatar was set successfully or is up to date
 	 */
-	public function updateAvatar($force = false) {
+	public function updateAvatar(bool $force = false): bool {
 		if (!$force && $this->wasRefreshed('avatar')) {
 			return false;
 		}
@@ -714,7 +701,7 @@ class User {
 		// use the checksum before modifications
 		$checksum = md5($this->image->data());
 
-		if ($checksum === $this->config->getUserValue($this->uid, 'user_ldap', 'lastAvatarChecksum', '')) {
+		if ($checksum === $this->config->getUserValue($this->uid, 'user_ldap', 'lastAvatarChecksum', '') && $this->avatarExists()) {
 			return true;
 		}
 
@@ -728,6 +715,15 @@ class User {
 		return $isSet;
 	}
 
+	private function avatarExists(): bool {
+		try {
+			$currentAvatar = $this->avatarManager->getAvatar($this->uid);
+			return $currentAvatar->exists() && $currentAvatar->isCustomAvatar();
+		} catch (\Exception $e) {
+			return false;
+		}
+	}
+
 	/**
 	 * @brief sets an image as Nextcloud avatar
 	 * @return bool
@@ -739,8 +735,8 @@ class User {
 		}
 
 
-		//make sure it is a square and not bigger than 128x128
-		$size = min([$this->image->width(), $this->image->height(), 128]);
+		//make sure it is a square and not bigger than 512x512
+		$size = min([$this->image->width(), $this->image->height(), 512]);
 		if (!$this->image->centerCrop($size)) {
 			$this->logger->error('croping image for avatar failed for '.$this->dn, ['app' => 'user_ldap']);
 			return false;
@@ -755,11 +751,7 @@ class User {
 			$avatar->set($this->image);
 			return true;
 		} catch (\Exception $e) {
-			\OC::$server->getLogger()->logException($e, [
-				'message' => 'Could not set avatar for ' . $this->dn,
-				'level' => ILogger::INFO,
-				'app' => 'user_ldap',
-			]);
+			$this->logger->info('Could not set avatar for ' . $this->dn, ['exception' => $e]);
 		}
 		return false;
 	}
@@ -789,7 +781,7 @@ class User {
 	 * @throws \OCP\PreConditionNotMetException
 	 * @throws \OC\ServerNotAvailableException
 	 */
-	public function updateExtStorageHome(string $valueFromLDAP = null):string {
+	public function updateExtStorageHome(?string $valueFromLDAP = null):string {
 		if ($valueFromLDAP === null) {
 			$extHomeValues = $this->access->readAttribute($this->getDN(), $this->connection->ldapExtStorageHomeAttribute);
 		} else {
@@ -812,7 +804,7 @@ class User {
 	 */
 	public function handlePasswordExpiry($params) {
 		$ppolicyDN = $this->connection->ldapDefaultPPolicyDN;
-		if (empty($ppolicyDN) || ((int)$this->connection->turnOnPasswordChange !== 1)) {
+		if (empty($ppolicyDN) || ((int) $this->connection->turnOnPasswordChange !== 1)) {
 			return;//password expiry handling disabled
 		}
 		$uid = $params['uid'];
@@ -846,13 +838,13 @@ class User {
 			//handle grace login
 			if (!empty($pwdGraceUseTime)) { //was this a grace login?
 				if (!empty($pwdGraceAuthNLimit)
-					&& count($pwdGraceUseTime) < (int)$pwdGraceAuthNLimit[0]) { //at least one more grace login available?
+					&& count($pwdGraceUseTime) < (int) $pwdGraceAuthNLimit[0]) { //at least one more grace login available?
 					$this->config->setUserValue($uid, 'user_ldap', 'needsPasswordReset', 'true');
 					header('Location: '.\OC::$server->getURLGenerator()->linkToRouteAbsolute(
-					'user_ldap.renewPassword.showRenewPasswordForm', ['user' => $uid]));
+						'user_ldap.renewPassword.showRenewPasswordForm', ['user' => $uid]));
 				} else { //no more grace login available
 					header('Location: '.\OC::$server->getURLGenerator()->linkToRouteAbsolute(
-					'user_ldap.renewPassword.showLoginFormInvalidPassword', ['user' => $uid]));
+						'user_ldap.renewPassword.showLoginFormInvalidPassword', ['user' => $uid]));
 				}
 				exit();
 			}
@@ -860,15 +852,15 @@ class User {
 			if (!empty($pwdReset) && $pwdReset[0] === 'TRUE') { //user must change his password
 				$this->config->setUserValue($uid, 'user_ldap', 'needsPasswordReset', 'true');
 				header('Location: '.\OC::$server->getURLGenerator()->linkToRouteAbsolute(
-				'user_ldap.renewPassword.showRenewPasswordForm', ['user' => $uid]));
+					'user_ldap.renewPassword.showRenewPasswordForm', ['user' => $uid]));
 				exit();
 			}
 			//handle password expiry warning
 			if (!empty($pwdChangedTime)) {
 				if (!empty($pwdMaxAge)
 					&& !empty($pwdExpireWarning)) {
-					$pwdMaxAgeInt = (int)$pwdMaxAge[0];
-					$pwdExpireWarningInt = (int)$pwdExpireWarning[0];
+					$pwdMaxAgeInt = (int) $pwdMaxAge[0];
+					$pwdExpireWarningInt = (int) $pwdExpireWarning[0];
 					if ($pwdMaxAgeInt > 0 && $pwdExpireWarningInt > 0) {
 						$pwdChangedTimeDt = \DateTime::createFromFormat('YmdHisZ', $pwdChangedTime[0]);
 						$pwdChangedTimeDt->add(new \DateInterval('PT'.$pwdMaxAgeInt.'S'));
