@@ -134,8 +134,6 @@ OC.L10N.register(
     "Account name" : "Όνομα λογαριασμού",
     "Server side authentication failed!" : "Αποτυχημένη πιστοποίηση από πλευράς διακομιστή!",
     "Please contact your administrator." : "Παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
-    "Temporary error" : "Προσωρινό σφάλμα",
-    "Please try again." : "Παρακαλώ δοκιμάστε ξανά.",
     "An internal error occurred." : "Παρουσιάστηκε ένα εσωτερικό σφάλμα.",
     "Please try again or contact your administrator." : "Παρακαλούμε δοκιμάστε ξανά ή επικοινωνήστε με τον διαχειριστή.",
     "Password" : "Συνθηματικό",
@@ -190,6 +188,12 @@ OC.L10N.register(
     "Back" : "Πίσω",
     "Login form is disabled." : "Η φόρμα σύνδεσης είναι απενεργοποιημένη.",
     "More actions" : "Περισσότερες ενέργειες",
+    "Password is too weak" : "Ο κωδικός πρόσβασης είναι πολύ αδύναμος",
+    "Password is weak" : "Ο κωδικός πρόσβασης είναι αδύναμος",
+    "Password is average" : "Ο κωδικός πρόσβασης είναι μέτριος",
+    "Password is strong" : "Ο κωδικός πρόσβασης είναι ισχυρός",
+    "Password is very strong" : "Ο κωδικός πρόσβασης είναι πολύ ισχυρός",
+    "Password is extremely strong" : "Ο κωδικός πρόσβασης είναι εξαιρετικά ισχυρός",
     "Security warning" : "Προειδοποίηση ασφαλείας",
     "Storage & database" : "Αποθηκευτικός χώρος & βάση δεδομένων",
     "Data folder" : "Φάκελος δεδομένων",
