@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Не вдалося увійти",
     "State token missing" : "Відсутній токен стану.",
     "Your login token is invalid or has expired" : "Ваш токен для входу неправильний або термін його дії вичерпано",
+    "Please use original client" : "Використовуйте оригінальний клієнт",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Цей випуск спільноти Nextcloud не підтримується, а push-сповіщення обмежені.",
     "Login" : "Вхід",
     "Unsupported email length (>255)" : "Довжина адреси ел.пошти не підтримується (більше 255 символів)",
@@ -105,10 +106,10 @@ OC.L10N.register(
     "Yes" : "Так",
     "The remote URL must include the user." : "Віддалена адреса повинна містити в собі імʼя користувача.",
     "Invalid remote URL." : "Недійсна віддалена адреса.",
-    "Failed to add the public link to your Nextcloud" : "Не вдалося додати загальнодоступне посилання до вашого Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Не вдалося додати публічне посилання до вашого Nextcloud",
     "Federated user" : "Обʼєднаний користувач",
     "user@your-nextcloud.org" : "користувач@ваш-nextcloud.org",
-    "Create share" : "Створити спільний ресурс",
+    "Create share" : "Передати у публічний доступ",
     "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
     "Please copy the link manually:" : "Будь ласка, скопіюйте посилання вручну:",
     "Custom date range" : "Власний вибір проміжку",
