@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Níl ceann scríbe ann",
     "Destination is not creatable" : "Níl ceann scríbe cruthaithe",
     "Dot files are not allowed" : "Ní cheadaítear comhaid ponc",
+    "%1$s (renamed)" : "%1$s (athainmnithe)",
+    "renamed file" : "comhad athainmnithe",
     "\"%1$s\" is a forbidden file or folder name." : "Is ainm toirmiscthe comhaid nó fillteáin é \"%1$s\".",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "Réimír toirmiscthe é \"%1$s\" d'ainmneacha comhaid nó fillteán.",
     "\"%1$s\" is not allowed inside a file or folder name." : "Ní cheadaítear \"%1$s\" taobh istigh d'ainm comhaid nó fillteáin.",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Tá an chonair roinnte leis an ngrúpa seo cheana féin",
     "Link sharing is not allowed" : "Ní cheadaítear nasc a roinnt",
     "Public upload is not allowed" : "Ní cheadaítear uaslódáil phoiblí",
+    "You cannot share a folder that contains other shares" : "Ní féidir leat fillteán a roinnt ina bhfuil scaireanna eile",
     "Sharing is disabled" : "Tá roinnt díchumasaithe",
     "Sharing is disabled for you" : "Tá comhroinnt díchumasaithe duit",
     "Cannot share with the share owner" : "Ní féidir a roinnt leis an úinéir na scaireanna",
@@ -272,6 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ní mór Logáil Isteach bailí a sholáthar",
     "Login contains whitespace at the beginning or at the end" : "Tá spás bán sa logáil isteach ag an tús nó ag an deireadh",
     "Login must not consist of dots only" : "Níor cheart go gcuimseodh logáil isteach poncanna amháin",
+    "Login is too long" : "Tá logáil isteach ró-fhada",
     "Login is invalid because files already exist for this user" : "Tá logáil isteach neamhbhailí toisc go bhfuil comhaid ann cheana don úsáideoir seo",
     "Account disabled" : "Díchumasaíodh an cuntas",
     "Login canceled by app" : "Cealaíodh logáil isteach ag an aip",
@@ -328,7 +332,6 @@ OC.L10N.register(
     "The audio to transcribe" : "Fuaime le tras-scríobh",
     "Transcription" : "Trascríobh",
     "The transcribed text" : "An téacs tras-scríofa",
-    "ContextAgent" : "Gníomhaire Comhthéacs",
     "Chat with an agent" : "Déan comhrá le gníomhaire",
     "Chat message" : "Teachtaireacht comhrá",
     "A chat message to send to the agent." : "Teachtaireacht comhrá le seoladh chuig an ngníomhaire.",
@@ -363,6 +366,11 @@ OC.L10N.register(
     "How many images to generate" : "Cé mhéad íomhánna atá le giniúint",
     "Output images" : "Íomhánna aschuir",
     "The generated images" : "Na híomhánna a ghintear",
+    "Generate speech" : "Gin urlabhra",
+    "Generate speech from a transcript" : "Gin urlabhra ó thrascríbhinn",
+    "Write transcript that you want the assistant to generate speech from" : "Scríobh an tras-scríbhinn ar mhaith leat go nginfeadh an cúntóir urlabhra uaidh",
+    "Output speech" : "Aschur cainte",
+    "The generated speech" : "An chaint ghinte",
     "Free text to text prompt" : "Teimpléad téacs go téacs saor in aisce,",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Ritheann leid treallach trí mhúnla teanga a sheolann freagra ar ais",
     "Describe a task that you want the assistant to do or ask a question" : "Déan cur síos ar thasc a theastaíonn uait don chúntóir a dhéanamh nó ceist a chur",
@@ -456,7 +464,6 @@ OC.L10N.register(
     "Click the button below to open it." : "Cliceáil ar an gcnaipe thíos chun é a oscailt.",
     "File is currently busy, please try again later" : "Tá an comhad gnóthach faoi láthair, bain triail eile as ar ball le do thoil",
     "Cannot download file" : "Ní féidir an comhad a íoslódáil",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Cinntigh go bhfuil comhad darb ainm \".ocdata\" i bhfréamh an eolaire sonraí.",
-    "Path contains files shared with you" : "Tá comhaid a roinntear leat sa chonair"
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Cinntigh go bhfuil comhad darb ainm \".ocdata\" i bhfréamh an eolaire sonraí."
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
